Crate csv_log_cleaner

Crate csv_log_cleaner 

Clean CSV files to conform to a type schema by streaming them through small memory buffers using multiple threads and logging data loss.

Documentation

Github

Structs

CSVCleansingError
Error representing a problem that occurred during the CSV cleaning process.
CleansingLog
Column
ColumnLog
Holds data on the invalid count and max and min invalid string values (calculated by String comparison) found in that column.
JsonColumn
JsonSchema

Functions

clean_csv
Clean CSV files to conform to a type schema by streaming them through small memory buffers using multiple threads and logging data loss.
get_schema_from_json_str
Extracts a Result containing a JsonSchema CSV cleansing specification from a JSON string specification.