Structs
- CSVCleansing
Error - Error representing a problem that occurred during the CSV cleaning process.
- Cleansing
Log - Column
- Column
Log - Holds data on the invalid count and max and min invalid string values (calculated by String comparison) found in that column.
- Json
Column - Json
Schema
Functions
- clean_
csv - Clean CSV files to conform to a type schema by streaming them through small memory buffers using multiple threads and logging data loss.
- get_
schema_ from_ json_ str - Extracts a Result containing a JsonSchema CSV cleansing specification from a JSON string specification.