Crate csv_log_cleaner

source ·
Clean CSV files to conform to a type schema by streaming them through small memory buffers using multiple threads and logging data loss.

Documentation

Github

Structs

Functions

  • Clean CSV files to conform to a type schema by streaming them through small memory buffers using multiple threads and logging data loss.
  • Extracts a Result containing a JsonSchema CSV cleansing specification from a JSON string specification.