Crate csv_log_cleaner
source ·Expand description
Clean CSV files to conform to a type schema by streaming them through small memory buffers using multiple threads and logging data loss.
Documentation
Structs
- Error representing a problem that occurred during the CSV cleaning process.
- Holds data on the invalid count and max and min invalid string values (calculated by String comparison) found in that column.
Functions
- Clean CSV files to conform to a type schema by streaming them through small memory buffers using multiple threads and logging data loss.
- Extracts a Result containing a JsonSchema CSV cleansing specification from a JSON string specification.